darkhistory.physics.C_He — DarkHistory documentation

# darkhistory.physics.C_He

`darkhistory.physics.` `C_He`(xHII, xHeII, rs, species)

  Helium C coefficients.

  These coefficients play a similar role to the Peebles C factor.

  Parameters: | xHII : float The HI ionization fraction nHII/nH. xHeII : float The HeI ionization fraction nHeII/nH. rs : float The redshift in 1+z. species : {‘singlet’, ‘triplet’} The relevant helium C coefficient to return.
  Returns: | float The C coefficient.

#### Previous topic

darkhistory.physics.peebles_C

#### Next topic

darkhistory.physics.xe_Saha

### This Page

Show Source